@@ -6,6 +6,7 @@ import re
 
 import bs4
 import compressed_rtf
+import RTFDE
 
 from . import constants
 from .attachment import Attachment, BrokenAttachment, UnsupportedAttachment
@@ -236,6 +237,11 @@ class MessageBase(MSGFile):
                 if a is not None:
                     if re.search('\r\n', self._body) is not None:
                         self.__crlf = '\r\n'
+            else:
+                # If the body doesn't exist, see if we can get it from the RTF
+                # body.
+                if self.deencapsulatedRtf and self.deencapsulatedRtf.content_type == 'text':
+                    self._body = self.deencapsulatedRtf.text
             return self._body
 
     @property
@@ -272,6 +278,29 @@ class MessageBase(MSGFile):
             self._date = self._prop.date
             return self._date
 
+    @property
+    def deencapsulatedRtf(self) -> RTFDE.DeEncapsulator:
+        """
+        Returns the instance of the deencapsulated RTF body.
+        """
+        try:
+            return self._deencapsultor
+        except AttributeError:
+            if self.rtfBody:
+                # If there is an RTF body, we try to deencapsulate it.
+                try:
+                    self._deencapsultor = RTFDE.DeEncapsulator(self.rtfBody)
+                    self._deencapsultor.deencapsulate()
+                except RTFDE.NotEncapsulatedRtf as e:
+                    logger.debug("RTF body is not encapsulated.")
+                    self._deencapsultor = None
+                except RTFDE.MalformedEncapsulatedRtf as _e:
+                    logger.info("RTF body contains malformed encapsulated content.")
+                    self._deencapsultor = None
+            else:
+                self._deencapsultor = None
+            return self._deencapsultor
+
     @property
     def defaultFolderName(self) -> str:
         """
@@ -335,7 +364,27 @@ class MessageBase(MSGFile):
         """
         Returns the html body, if it exists.
         """
-        return self._ensureSet('_htmlBody', '__substg1.0_10130102', False)
+        try:
+            return self._htmlBody
+        except AttributeError:
+            if self._ensureSet('_htmlBody', '__substg1.0_10130102', False):
+                # Reducing line repetition.
+                pass
+            elif self.rtfBody:
+                logger.info('HTML body was not found, attempting to generate from RTF.')
+                if self.deencapsulatedRtf and self.deencapsulatedRtf.content_type == 'html':
+                    self._htmlBody = self.deencapsulatedRtf.html.encode('utf-8')
+                else:
+                    logger.info('Could not deencapsulate HTML from RTF body.')
+            elif self.body:
+                # Convert the plain text body to html.
+                logger.info('HTML body was not found, attempting to generate from plain text body.')
+                correctedBody = self.body.encode('utf-8').replace('\r', '').replace('\n', '</br>')
+                self._htmlBody = f'<html><body>{correctedBody}</body></head>'
+            else:
+                logger.into('HTML body could not be found nor generated.')
+
+            return self._htmlBody
 
     @property
     def htmlBodyPrepared(self) -> bytes:
@@ -345,7 +394,7 @@ class MessageBase(MSGFile):
         """
         # If we can't get an HTML body then we have nothing to do.
         if not self.htmlBody:
-            return b''
+            return self.htmlBody
 
         # Create the BeautifulSoup instance to use.
         soup = bs4.BeautifulSoup(self.htmlBody, 'html.parser')
@@ -353,17 +402,17 @@ class MessageBase(MSGFile):
         # Get a list of image tags to see if we can inject into. If the source
         # of an image starts with "cid:" that means it is one of the attachments
         # and is using the content id of that attachment.
-        tags = tuple(tag for tag in soup.findAll('img') if tag.get('src') and tag.get('src').startswith('cid:'))
+        tags = (tag for tag in soup.findAll('img') if tag.get('src') and tag.get('src').startswith('cid:'))
 
         for tag in tags:
-            # Iterate through the attachments until we get the right
+            # Iterate through the attachments until we get the right one.
             cid = tag['src'][4:]
             data = next((attachment.data for attachment in self.attachments if attachment.cid == cid), None)
             # If we found anything, inject it.
             if data:
                 tag['src'] = (b'data:image;base64,' + base64.b64encode(data)).decode('utf-8')
 
-        return soup.prettify().encode('utf8')
+        return soup.prettify('utf-8')
 
     @property
     def inReplyTo(self) -> str:
