@@ -185,6 +185,9 @@ def getCommandArgs(args):
     # --prepared-html
     parser.add_argument('--prepared-html', dest='preparedHtml', action='store_true',
                         help='When used in conjunction with --html, sets whether the HTML output should be prepared for embedded attachments.')
+    # --charset
+    parser.add_argument('--charset', dest='charset', default='utf-8',
+                        help='Character set to use for the prepared HTML in the added tag. (Default: utf-8)')
     # --raw
     parser.add_argument('--raw', dest='raw', action='store_true',
                         help='Sets whether the output should be HTML. If this is not possible, will error.')
@@ -197,6 +200,9 @@ def getCommandArgs(args):
     # --zip
     parser.add_argument('--zip', dest='zip',
                         help='Path to use for saving to a zip file.')
+    # --attachments-only
+    parser.add_argument('--attachments-only', dest='attachmentsOnly', action='store_true',
+                        help='Specify to only save attachments from an msg file.')
     # --out-name NAME
     parser.add_argument('--out-name', dest='out_name',
                         help='Name to be used with saving the file output. Should come immediately after the file name.')
@@ -207,8 +213,8 @@ def getCommandArgs(args):
     options = parser.parse_args(args)
 
     # Check if more than one of the following arguments has been specified
-    if options.html + options.rtf + options.json + options.raw > 1:
-       raise IncompatibleOptionsError('Only one of these options may be selected at a time: --html, --json, --raw, --rtf')
+    if options.html + options.rtf + options.json + options.raw + options.attachmentsOnly > 1:
+       raise IncompatibleOptionsError('Only one of these options may be selected at a time: --html, --json, --raw, --rtf, --attachments-only')
 
     if options.dev or options.file_logging:
         options.verbose = True
